==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/Config/DeleteRemediationConfiguration.pm <==

package Paws::Config::DeleteRemediationConfiguration;
  use Moose;
  has ConfigRuleName => (is => 'ro', isa => 'Str', required => 1);
  has ResourceType => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteRemediationConfiguration');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Config::DeleteRemediationConfigurationResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Config::DeleteRemediationConfiguration - Arguments for method DeleteRemediationConfiguration on L<Paws::Config>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteRemediationConfiguration on the
L<AWS Config|Paws::Config> service. Use the attributes of this class
as arguments to method DeleteRemediationConfiguration.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteRemediationConfiguration.

=head1 SYNOPSIS

    my $config = Paws->service('Config');
    my $DeleteRemediationConfigurationResponse =
      $config->DeleteRemediationConfiguration(
      ConfigRuleName => 'MyStringWithCharLimit64',
      ResourceType   => 'MyString',                  # OPTIONAL
      );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/config/DeleteRemediationConfiguration>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ConfigRuleName => Str

The name of the AWS Config rule for which you want to delete
remediation configuration.



=head2 ResourceType => Str

The type of a resource.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteRemediationConfiguration in L<Paws::Config>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/Config/DeleteRemediationConfiguration.pm <==

package Paws::Config::DeleteRemediationConfiguration;
  use Moose;
  has ConfigRuleName => (is => 'ro', isa => 'Str', required => 1);
  has ResourceType => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteRemediationConfiguration');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Config::DeleteRemediationConfigurationResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Config::DeleteRemediationConfiguration - Arguments for method DeleteRemediationConfiguration on L<Paws::Config>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteRemediationConfiguration on the
L<AWS Config|Paws::Config> service. Use the attributes of this class
as arguments to method DeleteRemediationConfiguration.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteRemediationConfiguration.

=head1 SYNOPSIS

    my $config = Paws->service('Config');
    my $DeleteRemediationConfigurationResponse =
      $config->DeleteRemediationConfiguration(
      ConfigRuleName => 'MyConfigRuleName',
      ResourceType   => 'MyString',           # OPTIONAL
      );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/config/DeleteRemediationConfiguration>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ConfigRuleName => Str

The name of the AWS Config rule for which you want to delete
remediation configuration.



=head2 ResourceType => Str

The type of a resource.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteRemediationConfiguration in L<Paws::Config>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
